#
# spec file for package libdatachannel
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#%%define soversion() %%(echo "%%{1}" | awk -F. '{print $1"."$2}')
%define soversion 0_21
%define libname %{name}%{soversion}
Name:           libdatachannel
Version:        0.21.2
Release:        1699.1.pm.1
Summary:        WebRTC network library featuring Data Channels, Media Transport, and WebSockets
License:        MPL-2.0
URL:            https://libdatachannel.org/
Group:          Development/Libraries/C and C++
Source0:        https://github.com/paullouisageneau/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gawk
BuildRequires:  gcc-c++
BuildRequires:  libsrtp-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  usrsctp-devel
# Not yet needed and not packaged in openSUSE yet
#BuildRequires:  cmake(LibJuice)
BuildRequires:  pkgconfig(libsrtp2)
BuildRequires:  pkgconfig(nlohmann_json) >= 3
BuildRequires:  cmake(plog)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(nice)

%description
libdatachannel is a standalone implementation of WebRTC Data Channels,
WebRTC Media Transport, and WebSockets in C++17 with C bindings for POSIX platforms
(including GNU/Linux, Android, FreeBSD, Apple macOS and iOS) and Microsoft Windows.

%package -n	%{libname}
Summary:        C++ library for %{name}
Group:          System/Libraries

%description -n	%{libname}
libdatachannel is a standalone implementation of WebRTC Data Channels,
WebRTC Media Transport, and WebSockets in C++17 with C bindings for POSIX platforms
(including GNU/Linux, Android, FreeBSD, Apple macOS and iOS) and Microsoft Windows.

%package        devel
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup

%build
%cmake -DPREFER_SYSTEM_LIB=ON -DUSE_GNUTLS=ON -DUSE_NICE=ON
%cmake_build

%install
%cmake_install

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%{_libdir}/%{name}.so.*

%files devel
%doc README.md DOC.md
%{_includedir}/rtc/
%{_libdir}/cmake/LibDataChannel/
%{_libdir}/%{name}.so

%changelog
* Sat Jul 13 2024 ecsos <ecsos@opensuse.org>
- Update to 0.21.2
  - Fix uninitialized playout delay fields in RtpPacketizationConfig by @paullouisageneau in #1217
  - Fix missing notify on queue limit preventing thread from waking up by @paullouisageneau in #1221
- Changes from 0.21.1
  - Fix multiple NAL units handling in H264RtpDepacketizer by @paullouisageneau in #1167
  - Prevent TcpTransport initialization errors from stopping TcpServer by @paullouisageneau in #1175
  - Reduce per-channel receive queue limit to 1024 by @paullouisageneau in #1179
  - Fix importing certificate from string with Mbed TLS by @paullouisageneau in #1180
  - Fix missing algorithm header in h264rtpdepacketizer.cpp by @paullouisageneau in #1183
  - Update libjuice to v1.4.2: If socket allocation fails try again without IPv6
* Tue May  7 2024 ecsos <ecsos@opensuse.org>
- Update to 0.21.0
  - Add version macros in #1112
  - Add H264RtpDepacketizer in #1082
  - Add OpusRtpDepacketizer in #1123
  - Bump mio from 0.8.8 to 0.8.11 in /examples/signaling-server-rust in #1126
  - Bump es5-ext from 0.10.53 to 0.10.63 in /examples/signaling-server-nodejs in #1119
  - media-receiver example: Add save to file pipe & requirements in #1136
  - Fix H264RtpDepacketizer to handle empty payload RTP packet in #1140
  - Fix misaligned dereference in H264 and H265 packetizers in #1157
  - Include payloadType in FrameInfo in #1156
  - Add playout delay extension support in #1152
  - H264RtpDepacketizer: De-packetize access units rather than individual NALUs in #1135
  - Add PacingHandler in #1153
  - Add PeerConnection::setConfiguration() method in #920
* Tue May  7 2024 ecsos <ecsos@opensuse.org>
- Update to 0.20.3
  - Fix crash in IceTransport::TimeoutCallback with libnice in #1103
  - Disable TLS 1.3 with Mbed TLS in #1148
  - Change deprecated OpenSSL version-flexible TLS method in #1149
  - Fix MbedTLS usage bugs and allow cmake to use imported mbedtls library in #1154
* Wed Mar 13 2024 ecsos <ecsos@opensuse.org>
- Update to 0.20.2
  - Fix track creation synchronizationin #1109
  - Fix NACK messages corruptionin #1118
  - Fix iterator past end of vectorin #1128
  - Fix rtcSetSignalingStateChangeCallback reset#1129
- Changes from 0.20.1
  - Fix compatibility with old system usrsctp v0.9.5.0 in #1099
- Changes from 0.20.0
  - Allow setting CA certificate during TLS connection in #1009
  - Implement missing methods of RtcpReportBlock in #1013
  - Add a media handler to respond to intra frame requests in #999
  - Add PLI handler to C API in #1019
  - Add track and user pointer to PLI handler callback in C API in #1021
  - Refactor media handlers in #929
  - Rename Description::addAacCodec() to addAACCodec for consistency in #1022
  - Set SCTP zero checksum in #1015
  - Fix segfault caused by RtcpReceivingSession in #1027
  - Correct NTP of Sender Report in #1028
  - Refactor Data Channel reliability API in #1031
  - Forward RTP/RTCP messages unconditionally if there is only one track in #1023
  - Fix the target location of the FU header pointer in #1037
  - Access mbedtls private member via a portable macro in #1040
  - Set SNI for MbedTLS in #1041
  - Improve example command-line help in #1049
  - Use caCertificatePemFile in OpenSSL backend in #1047
  - WebSocket: allow clients to provide a TLS certificate in #1062
  - Fix RtcpReportBlock::setPacketsLost() in #1069
  - Add maxMessageSize to Websocket configuration in #1086
  - Support all Certificate Fingerprint Algorithms in #1077
  - Configure datachannel target_properties for APPLE in #1091
  - Enforce WebSocket max message size at reception in #1094
  - Move operator<< to rtc namespace in #1096
  - Unmap WebSocket remote IPv4-mapped IPv6 addresses in #1097
  - Add RtcpReceivingSession support to C API in #1029
  - libjuice v1.3.4: Fix misalignment issue during STUN data reading
- Changes from 0.19.5
  - Add #include to fix building with gcc 14 in #1055
  - Ensure rtpExtHeaderSize is a multiple of 4 in #1061
  - H265NalUnitFragment: Mask nuhTempIdPlus1 correctly in #1073
  - Use prime256v1 for EVP_EC_gen instead of P-256 in #1075
  - Fix media description m-line parsing in #1081
- Changes from 0.19.4
  - Add virtual destructor to MediaHandler in #1025
  - Fix key generation check for legacy OpenSSL in #1042
  - Correct NTP of Sender Report in #1028
  - Fix the target location of the FU header pointer in #1037
  - Access MbedTLS private member via a portable macro in #1040
  - Set SNI for MbedTLS in #1041
* Sun Nov 12 2023 ecsos <ecsos@opensuse.org>
- Initial version 0.19.3
